summaryrefslogtreecommitdiffstats
path: root/libtdepim/kfoldertree.cpp
diff options
context:
space:
mode:
authorTimothy Pearson <kb9vqf@pearsoncomputing.net>2013-02-01 15:14:12 -0600
committerTimothy Pearson <kb9vqf@pearsoncomputing.net>2013-02-01 15:14:12 -0600
commitfd5d099065a748cac49e20a13481f85666c53c71 (patch)
treea0f1672cd88eb0e69b9ddc2ed9b08ecd98538bd3 /libtdepim/kfoldertree.cpp
parentb440a9c608596cd88efdb3bfa4661c5e37efbe4b (diff)
downloadtdepim-fd5d099065a748cac49e20a13481f85666c53c71.tar.gz
tdepim-fd5d099065a748cac49e20a13481f85666c53c71.zip
Rename a number of classes to enhance compatibility with KDE4
Diffstat (limited to 'libtdepim/kfoldertree.cpp')
-rw-r--r--libtdepim/kfoldertree.cpp22
1 files changed, 11 insertions, 11 deletions
diff --git a/libtdepim/kfoldertree.cpp b/libtdepim/kfoldertree.cpp
index 58961ddc..abc69fad 100644
--- a/libtdepim/kfoldertree.cpp
+++ b/libtdepim/kfoldertree.cpp
@@ -14,7 +14,7 @@
//-----------------------------------------------------------------------------
KFolderTreeItem::KFolderTreeItem( KFolderTree *parent, const TQString & label,
Protocol protocol, Type type )
- : KListViewItem( parent, label ), mProtocol( protocol ), mType( type ),
+ : TDEListViewItem( parent, label ), mProtocol( protocol ), mType( type ),
mUnread(-1), mTotal(0), mSize(0), mFolderIsCloseToQuota( false )
{
}
@@ -23,7 +23,7 @@ KFolderTreeItem::KFolderTreeItem( KFolderTree *parent, const TQString & label,
KFolderTreeItem::KFolderTreeItem( KFolderTreeItem *parent,
const TQString & label, Protocol protocol, Type type,
int unread, int total )
- : KListViewItem( parent, label ), mProtocol( protocol ), mType( type ),
+ : TDEListViewItem( parent, label ), mProtocol( protocol ), mType( type ),
mUnread( unread ), mTotal( total ), mSize(0), mFolderIsCloseToQuota( false )
{
}
@@ -265,7 +265,7 @@ void KFolderTreeItem::paintCell( TQPainter * p, const TQColorGroup & cg,
}
// most cells can be handled by KListView::paintCell, we only need to
// deal with the folder column if the unread column is not shown
/* The below is exceedingly silly, but Ingo insists that the unread
@@ -274,16 +274,16 @@ void KFolderTreeItem::paintCell( TQPainter * p, const TQColorGroup & cg,
* two painting passes which flickers. Since that flicker is not
* needed when there is the unread column, special case that. */
if ( ft->isUnreadActive() || column != 0 ) {
- KListViewItem::paintCell( p, mycg, column, width, align );
+ TDEListViewItem::paintCell( p, mycg, column, width, align );
} else {
TQListView *lv = listView();
TQString oldText = text(column);
// set an empty text so that we can have our own implementation (see further down)
// but still benefit from KListView::paintCell
setText( column, "" );
- KListViewItem::paintCell( p, mycg, column, width, align );
+ TDEListViewItem::paintCell( p, mycg, column, width, align );
const TQPixmap *icon = pixmap( column );
int marg = lv ? lv->itemMargin() : 1;
@@ -360,7 +360,7 @@ void KFolderTreeItem::setFolderIsCloseToQuota( bool v )
KFolderTree::KFolderTree( TQWidget *parent, const char* name )
- : KListView( parent, name ), mUnreadIndex(-1), mTotalIndex(-1), mSizeIndex(-1)
+ : TDEListView( parent, name ), mUnreadIndex(-1), mTotalIndex(-1), mSizeIndex(-1)
{
// GUI-options
setStyleDependantFrameWidth();
@@ -404,7 +404,7 @@ void KFolderTree::setStyleDependantFrameWidth()
void KFolderTree::styleChange( TQStyle& oldStyle )
{
setStyleDependantFrameWidth();
- KListView::styleChange( oldStyle );
+ TDEListView::styleChange( oldStyle );
}
//-----------------------------------------------------------------------------
@@ -413,7 +413,7 @@ void KFolderTree::drawContentsOffset( TQPainter * p, int ox, int oy,
{
bool oldUpdatesEnabled = isUpdatesEnabled();
setUpdatesEnabled(false);
- KListView::drawContentsOffset( p, ox, oy, cx, cy, cw, ch );
+ TDEListView::drawContentsOffset( p, ox, oy, cx, cy, cw, ch );
setUpdatesEnabled(oldUpdatesEnabled);
}
@@ -421,13 +421,13 @@ void KFolderTree::drawContentsOffset( TQPainter * p, int ox, int oy,
void KFolderTree::contentsMousePressEvent( TQMouseEvent *e )
{
setSelectionModeExt(Single);
- KListView::contentsMousePressEvent(e);
+ TDEListView::contentsMousePressEvent(e);
}
//-----------------------------------------------------------------------------
void KFolderTree::contentsMouseReleaseEvent( TQMouseEvent *e )
{
- KListView::contentsMouseReleaseEvent(e);
+ TDEListView::contentsMouseReleaseEvent(e);
setSelectionModeExt(Extended);
}
@@ -265,7 +265,7 @@ void KFolderTreeItem::paintCell( TQPainter * p, const TQColorGroup & cg,
}
- // most cells can be handled by KListView::paintCell, we only need to
+ // most cells can be handled by TDEListView::paintCell, we only need to
// deal with the folder column if the unread column is not shown
/* The below is exceedingly silly, but Ingo insists that the unread
@@ -274,16 +274,16 @@ void KFolderTreeItem::paintCell( TQPainter * p, const TQColorGroup & cg,
TQString oldText = text(column);
// set an empty text so that we can have our own implementation (see further down)
- // but still benefit from KListView::paintCell
+ // but still benefit from TDEListView::paintCell
setText( column, "" );